searchData={"items":[{"type":"module","title":"GitHooks.Tasks.Cmd","doc":"Represents a command that will be executed as a git hook task.\n\nA command should be configured as `{:cmd, command, opts}`, being `opts` an\noptional configuration.\n\nFor example:\n\n```elixir\nconfig :git_hooks,\n  hooks: [\n    pre_commit: [\n      {:cmd, \"ls -lisa\", include_hook_args: true}\n    ]\n  ]\n```","ref":"GitHooks.Tasks.Cmd.html"},{"type":"function","title":"GitHooks.Tasks.Cmd.new/3","doc":"Creates a new `cmd` struct that will execute a command.\n\nThis function expects a tuple or triple with `:cmd`, the command to execute\nand the opts.","ref":"GitHooks.Tasks.Cmd.html#new/3"},{"type":"function","title":"Options - GitHooks.Tasks.Cmd.new/3","doc":"* `include_hook_args`: Whether the git options will be passed as argument when\nexecuting the file. You will need to check [which arguments are being sent by each git hook](https://git-scm.com/docs/githooks).\n* `env`: The environment variables that will be set in the execution context of the file.","ref":"GitHooks.Tasks.Cmd.html#new/3-options"},{"type":"function","title":"Examples - GitHooks.Tasks.Cmd.new/3","doc":"iex> Elixir.GitHooks.Tasks.Cmd.new({:cmd, \"ls -l\", env: [{\"var\", \"test\"}], include_hook_args: true}, :pre_commit, [\"commit message\"])\n    %Elixir.GitHooks.Tasks.Cmd{command: \"ls\", original_command: \"ls -l\", args: [\"-l\", \"commit message\"], env: [{\"var\", \"test\"}], git_hook_type: :pre_commit}\n\n    iex> Elixir.GitHooks.Tasks.Cmd.new({:cmd, \"ls\", include_hook_args: false}, :pre_commit, [\"commit message\"])\n    %Elixir.GitHooks.Tasks.Cmd{command: \"ls\", original_command: \"ls\", args: [], env: [], git_hook_type: :pre_commit}","ref":"GitHooks.Tasks.Cmd.html#new/3-examples"},{"type":"type","title":"GitHooks.Tasks.Cmd.t/0","doc":"Represents a `command` to be executed.","ref":"GitHooks.Tasks.Cmd.html#t:t/0"},{"type":"module","title":"GitHooks.Tasks.File","doc":"Represents a file that will be executed as a git hook task.\n\nA file should be configured as `{:file, file_path, opts}`, being `opts` an\noptional configuration. The file should be readable and have execution\npermissions.\n\nSee `Elixir.GitHooks.Tasks.File.new/1` for more information.\n\nFor example:\n\n```elixir\nconfig :git_hooks,\n  hooks: [\n    pre_commit: [\n      {:file, \"opt/scripts/checks\", include_hook_args: true}\n    ]\n  ]\n```","ref":"GitHooks.Tasks.File.html"},{"type":"function","title":"GitHooks.Tasks.File.new/3","doc":"Creates a new `file` struct.\n\nThis function expects a tuple or triple with `:file`, the file path and\nthe opts.","ref":"GitHooks.Tasks.File.html#new/3"},{"type":"function","title":"Options - GitHooks.Tasks.File.new/3","doc":"* `include_hook_args`: Whether the git options will be passed as argument when\nexecuting the file. You will need to check [which arguments are being sent by each git hook](https://git-scm.com/docs/githooks).\n* `env`: The environment variables that will be set in the execution context of the file.","ref":"GitHooks.Tasks.File.html#new/3-options"},{"type":"function","title":"Examples - GitHooks.Tasks.File.new/3","doc":"iex> Elixir.GitHooks.Tasks.File.new({:file, :test, env: [{\"var\", \"test\"}], include_hook_args: true}, :pre_commit, [\"commit message\"])\n    %Elixir.GitHooks.Tasks.File{file_path: :test, args: [\"commit message\"], env: [{\"var\", \"test\"}], git_hook_type: :pre_commit}\n\n    iex> Elixir.GitHooks.Tasks.File.new({:file, :test, include_hook_args: false}, :pre_commit, [\"commit message\"])\n    %Elixir.GitHooks.Tasks.File{file_path: :test, args: [], env: [], git_hook_type: :pre_commit}","ref":"GitHooks.Tasks.File.html#new/3-examples"},{"type":"type","title":"GitHooks.Tasks.File.t/0","doc":"Represents a `file` to be executed.","ref":"GitHooks.Tasks.File.html#t:t/0"},{"type":"module","title":"GitHooks.Tasks.MFA","doc":"Represents a `{module, function, arity}` (a.k.a. `mfa`) that will be evaluated\nby the Kernel module.\n\nAn `mfa` should be configured as `{module, function, arity}`. The function of\nthe module **will always receive the hook arguments** and the arity is\nexpected to match the same number to avoid any unexpected behaviour.\n\nSee [Elixir documentation](https://hexdocs.pm/elixir/typespecs.html#types-and-their-syntax) for more information.\n\nFor example:\n\n```elixir\nconfig :git_hooks,\n  hooks: [\n    pre_commit: [\n      {MyModule, :my_function, 1}\n    ]\n  ]\n```","ref":"GitHooks.Tasks.MFA.html"},{"type":"function","title":"GitHooks.Tasks.MFA.new/3","doc":"Creates a new `mfa` struct.","ref":"GitHooks.Tasks.MFA.html#new/3"},{"type":"function","title":"Examples - GitHooks.Tasks.MFA.new/3","doc":"iex> Elixir.GitHooks.Tasks.MFA.new({MyModule, :my_function, 1}, :pre_commit, [\"commit message\"])\n    %Elixir.GitHooks.Tasks.MFA{module: MyModule, function: :my_function, args: [\"commit message\"]}","ref":"GitHooks.Tasks.MFA.html#new/3-examples"},{"type":"type","title":"GitHooks.Tasks.MFA.t/0","doc":"Represents an `mfa` to be executed.","ref":"GitHooks.Tasks.MFA.html#t:t/0"},{"type":"module","title":"GitHooks.Tasks.Mix","doc":"Represents a Mix task that will be executed as a git hook task.\n\nA mix task should be configured as `{:mix_task, task_name, task_args}`,\nbeing `task_args` an optional configuration. See `Elixir.GitHooks.Tasks.Mix.new/1` for\nmore information.\n\nFor example:\n\n```elixir\nconfig :git_hooks,\n  hooks: [\n    pre_commit: [\n      {:mix_task, :test},\n      {:mix_task, :format, [\"--dry-run\"]}\n    ]\n  ]\n```\n\nSee `https://hexdocs.pm/mix/Mix.Task.html#run/2` for reference.","ref":"GitHooks.Tasks.Mix.html"},{"type":"function","title":"GitHooks.Tasks.Mix.new/1","doc":"Creates a new Mix task struct.\n\nThis function expects a tuple or triple with `:mix_task`, the task name and\nthe task args.","ref":"GitHooks.Tasks.Mix.html#new/1"},{"type":"function","title":"Examples - GitHooks.Tasks.Mix.new/1","doc":"iex> Elixir.GitHooks.Tasks.Mix.new({:mix_task, :test, [\"--failed\"]})\n    %Elixir.GitHooks.Tasks.Mix{task: :test, args: [\"--failed\"]}","ref":"GitHooks.Tasks.Mix.html#new/1-examples"},{"type":"type","title":"GitHooks.Tasks.Mix.t/0","doc":"Represents a Mix task.","ref":"GitHooks.Tasks.Mix.html#t:t/0"},{"type":"task","title":"mix git_hooks.install","doc":"Installs the configured git hooks.\n\nBefore installing the new hooks, the already hooks files are backed up\nwith the extension `.pre_git_hooks_backup`.","ref":"Mix.Tasks.GitHooks.Install.html"},{"type":"task","title":"Command line options - mix git_hooks.install","doc":"* `--quiet` - disables the output of the files that are being copied/backed up\n\nTo manually install the git hooks run:\n\n```elixir\nmix git_hooks.install`\n```","ref":"Mix.Tasks.GitHooks.Install.html#module-command-line-options"},{"type":"task","title":"mix git_hooks.run","doc":"Runs all the configured mix tasks for a given git hook.\n\nAny [git hook](https://git-scm.com/docs/githooks) is supported.","ref":"Mix.Tasks.GitHooks.Run.html"},{"type":"task","title":"Examples - mix git_hooks.run","doc":"You can run any hook by running `mix git_hooks.run hook_name`. For example:\n\n```elixir\nmix git_hooks.run pre_commit\n```\n\nYou can also all the hooks which are configured with `mix git_hooks.run all`.","ref":"Mix.Tasks.GitHooks.Run.html#module-examples"},{"type":"function","title":"Mix.Tasks.GitHooks.Run.run/1","doc":"Runs a task for a given git hook.\n\nThe task can be one of three different types:\n\n* `{:cmd, \"command arg1 arg2\"}`: Runs a command.\n* `{:file, \"path_to_file\"}`: Runs an executable file.\n* `\"command arg1 arg2\"`: Runs a simple command, supports no options.\n\nThe first two options above can use a third element in the tuple, see\n[here](`t:run_opts/0`) more info about the options.","ref":"Mix.Tasks.GitHooks.Run.html#run/1"},{"type":"type","title":"Mix.Tasks.GitHooks.Run.run_opts/0","doc":"Run options:\n\n* `include_hook_args`: Whether the git hook args should be sent to the\ncommand to be executed. In case of `true`, the args will be amended to the\ncommand. Defaults to `false`.","ref":"Mix.Tasks.GitHooks.Run.html#t:run_opts/0"},{"type":"extras","title":"Code of Conduct","doc":"# Contributor Covenant Code of Conduct","ref":"code_of_conduct.html"},{"type":"extras","title":"Our Pledge - Code of Conduct","doc":"In the interest of fostering an open and welcoming environment, we as\ncontributors and maintainers pledge to making participation in our project and\nour community a harassment-free experience for everyone, regardless of age, body\nsize, disability, ethnicity, sex characteristics, gender identity and expression,\nlevel of experience, education, socio-economic status, nationality, personal\nappearance, race, religion, or sexual identity and orientation.","ref":"code_of_conduct.html#our-pledge"},{"type":"extras","title":"Our Standards - Code of Conduct","doc":"Examples of behavior that contributes to creating a positive environment\ninclude:\n\n* Using welcoming and inclusive language\n* Being respectful of differing viewpoints and experiences\n* Gracefully accepting constructive criticism\n* Focusing on what is best for the community\n* Showing empathy towards other community members\n\nExamples of unacceptable behavior by participants include:\n\n* The use of sexualized language or imagery and unwelcome sexual attention or\n advances\n* Trolling, insulting/derogatory comments, and personal or political attacks\n* Public or private harassment\n* Publishing others' private information, such as a physical or electronic\n address, without explicit permission\n* Other conduct which could reasonably be considered inappropriate in a\n professional setting","ref":"code_of_conduct.html#our-standards"},{"type":"extras","title":"Our Responsibilities - Code of Conduct","doc":"Project maintainers are responsible for clarifying the standards of acceptable\nbehavior and are expected to take appropriate and fair corrective action in\nresponse to any instances of unacceptable behavior.\n\nProject maintainers have the right and responsibility to remove, edit, or\nreject comments, commits, code, wiki edits, issues, and other contributions\nthat are not aligned to this Code of Conduct, or to ban temporarily or\npermanently any contributor for other behaviors that they deem inappropriate,\nthreatening, offensive, or harmful.","ref":"code_of_conduct.html#our-responsibilities"},{"type":"extras","title":"Scope - Code of Conduct","doc":"This Code of Conduct applies both within project spaces and in public spaces\nwhen an individual is representing the project or its community. Examples of\nrepresenting a project or community include using an official project e-mail\naddress, posting via an official social media account, or acting as an appointed\nrepresentative at an online or offline event. Representation of a project may be\nfurther defined and clarified by project maintainers.","ref":"code_of_conduct.html#scope"},{"type":"extras","title":"Enforcement - Code of Conduct","doc":"Instances of abusive, harassing, or otherwise unacceptable behavior may be\nreported by contacting the project team at qgadrian@users.noreply.github.com. All\ncomplaints will be reviewed and investigated and will result in a response that\nis deemed necessary and appropriate to the circumstances. The project team is\nobligated to maintain confidentiality with regard to the reporter of an incident.\nFurther details of specific enforcement policies may be posted separately.\n\nProject maintainers who do not follow or enforce the Code of Conduct in good\nfaith may face temporary or permanent repercussions as determined by other\nmembers of the project's leadership.","ref":"code_of_conduct.html#enforcement"},{"type":"extras","title":"Attribution - Code of Conduct","doc":"This Code of Conduct is adapted from the [Contributor Covenant][homepage], version 1.4,\navailable at https://www.contributor-covenant.org/version/1/4/code-of-conduct.html\n\n[homepage]: https://www.contributor-covenant.org\n\nFor answers to common questions about this code of conduct, see\nhttps://www.contributor-covenant.org/faq","ref":"code_of_conduct.html#attribution"},{"type":"extras","title":"License","doc":"MIT License\n\nCopyright (c) 2018 Adrián Quintás\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"},{"type":"extras","title":"README","doc":"[![Coverage Status](https://coveralls.io/repos/github/qgadrian/elixir_git_hooks/badge.svg?branch=master)](https://coveralls.io/github/qgadrian/elixir_git_hooks?branch=master)\n[![Hex version](https://img.shields.io/hexpm/v/sippet.svg \"Hex version\")](https://hex.pm/packages/git_hooks)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-9768d1.svg)](https://hexdocs.pm/git_hooks)\n[![Build Status](https://travis-ci.org/qgadrian/elixir_git_hooks.svg?branch=master)](https://travis-ci.org/qgadrian/elixir_git_hooks.svg?branch=master)\n[![Inline docs](http://inch-ci.org/github/qgadrian/elixir_git_hooks.svg)](http://inch-ci.org/github/qgadrian/elixir_git_hooks)\n\n# GitHooks 🪝\n\n<!--toc:start-->\n\n- [Project description](#project-description)\n  - [Why use git hooks?](#why-use-git-hooks)\n- [Installation](#installation)\n  - [Backup current hooks](#backup-current-hooks)\n  - [Automatic installation](#automatic-installation)\n  - [Manual installation](#manual-installation)\n- [Configuration](#configuration)\n  - [Auto install](#auto-install)\n  - [Hook configuration](#hook-configuration)\n  - [Git submodules](#git-submodules)\n  - [Custom project path](#custom-project-path)\n  - [Custom mix path](#custom-mix-path)\n    - [Troubleshooting in docker containers](#troubleshooting-in-docker-containers)\n  - [Example config](#example-config)\n  - [Task types](#task-types)\n    - [Mix task](#mix-task)\n    - [Command](#command)\n    - [Executable file](#executable-file)\n    - [Elixir module](#elixir-module)\n- [Removing a hook](#removing-a-hook)\n- [Recipes](#recipes)\n  - [Running pre-commit hook only for staged files](#running-pre-commit-hook-only-for-staged-files)\n- [Execution](#execution)\n  - [Automatic execution](#automatic-execution)\n  - [Manual execution](#manual-execution)\n- [Copyright and License](#copyright-and-license)\n<!--toc:end-->","ref":"readme.html"},{"type":"extras","title":"Project description - README","doc":"Configure [git hooks](https://git-scm.com/docs/githooks) in your Elixir projects.\n\n#### Why use git hooks?\n\n- Enforces code quality: Automatically run tests, formatters, linters... before every\n  commit or push to ensure code consistency.\n- Prevent errors earlier: Catch issues with `pre-commit` or `pre-push`, reducing the\n  chance of broken builds and saving minutes and time in the CI or code review.\n- Improve workflows: Automate repetitive tasks, unify command execution, ensure\n  consistent standards across the team...\n\nMain features:\n\n- **Simplicity**: Automatic or manually install the configured git hook actions.\n- **Flexibility**: You choose what to use to define the git hooks actions:\n  - Bash commands\n  - Executable files\n  - Elixir modules\n- **No limits**: Any git hook is and will be supported out of the box,\n  you can [check here the git hooks list](https://git-scm.com/docs/githooks)\n  available.","ref":"readme.html#project-description"},{"type":"extras","title":"Installation - README","doc":"Add to dependencies:\n\n```elixir\ndef deps do\n  [\n    {:git_hooks, \"~> 0.8.0\", only: [:dev], runtime: false}\n  ]\nend\n```\n\nThen install and compile the dependencies:\n\n```bash\nmix deps.get && mix deps.compile\n```","ref":"readme.html#installation"},{"type":"extras","title":"Backup current hooks - README","doc":"This library will backup automatically your current git hooks before\noverwriting them.\n\nThe backup files will have the file extension `.pre_git_hooks_backup`","ref":"readme.html#backup-current-hooks"},{"type":"extras","title":"Automatic installation - README","doc":"This library will install automatically the configured git hooks in your\n`config.exs` file.\n\nSee [configuration](#disable-auto-install) to disable the automatic install.","ref":"readme.html#automatic-installation"},{"type":"extras","title":"Manual installation - README","doc":"If you prefer **not to enforce git hooks in a project**, you can still define\nrecommended hooks and allow team members to install them manually by running:\n\n```bash\nmix git_hooks.install\n```","ref":"readme.html#manual-installation"},{"type":"extras","title":"Configuration - README","doc":"","ref":"readme.html#configuration"},{"type":"extras","title":"Auto install - README","doc":"To disable the automatic install of the git hooks set the configuration key `auto_install` to\n`false`.","ref":"readme.html#auto-install"},{"type":"extras","title":"Hook configuration - README","doc":"One or more git hooks can be configured, those hooks will be the ones\n[installed](#installation) in your git project.\n\nCurrently there are supported two configuration options:\n\n- **tasks**: A list of the commands that will be executed when running a git hook. [See types of tasks](#type-of-tasks) for more info.\n- **verbose**: If true, the output of the mix tasks will be visible. This can be configured globally or per git hook.\n- **branches**: Allow or forbid the hook configuration to run (or not) in certain branches using `whitelist` or `blacklist` configuration (see example below). You can use regular expressions to match a branch name.","ref":"readme.html#hook-configuration"},{"type":"extras","title":"Git submodules - README","doc":"This library supports git submodules, just add your `git_hooks` configuration to\nany of the submodules projects.\n\nSetting a custom _git hooks_ config path is also supported:\n\n```\ngit config core.hooksPath .myCustomGithooks/\n```","ref":"readme.html#git-submodules"},{"type":"extras","title":"Custom project path - README","doc":"This library assumes a simple Elixir project architecture. This is, an Elixir\nproject in the root of a git repository.\n\nIf you have a different project architecture, you can specify the absolute path\nof your project using the `project_path` configuration:\n\n```elixir\n{project_path, 0} = System.cmd(\"pwd\", [])\nproject_path = String.replace(project_path, ~r/\\n/, \"/\")\n\nconfig :git_hooks,\n  hooks: [\n    pre_commit: [\n      tasks: [\n        {:cmd, \"mix format --check-formatted\"}\n      ]\n    ]\n  ],\n  project_path: project_path\n```","ref":"readme.html#custom-project-path"},{"type":"extras","title":"Custom mix path - README","doc":"This library expects `elixir` to be installed in your system and the `mix` binary to be available. If you want to provide a specific path to run the `mix` executable, it can be done using the `mix_path` configuration.\n\nThe following example would run the hooks on a docker container:\n\n```elixir\nconfig :git_hooks,\n  auto_install: false,\n  mix_path: \"docker-compose exec mix\",\n```\n\n##### Troubleshooting in docker containers\n\nThe `mix_path` configuration can be used to run mix hooks on a Docker container.\nIf you have a TTY error running mix in a Docker container use `docker exec --tty $(docker-compose ps -q web) mix` as the `mix_path`. See this [issue](https://github.com/qgadrian/elixir_git_hooks/issues/82) as reference.","ref":"readme.html#custom-mix-path"},{"type":"extras","title":"Example config - README","doc":"In `config/config.exs`\n\n```elixir\nuse Mix.Config\n\n# somewhere in your config file\nif Mix.env() == :dev do\n  config :git_hooks,\n    auto_install: true,\n    verbose: true,\n    branches: [\n      whitelist: [\"feature-.*\"],\n      blacklist: [\"master\"]\n    ],\n    hooks: [\n      pre_commit: [\n        tasks: [\n          {:cmd, \"mix format --check-formatted\"}\n        ]\n      ],\n      pre_push: [\n        verbose: false,\n        tasks: [\n          {:cmd, \"mix dialyzer\"},\n          {:cmd, \"mix test --color\"},\n          {:cmd, \"echo 'success!'\"}\n        ]\n      ]\n    ]\nend\n```","ref":"readme.html#example-config"},{"type":"extras","title":"Task types - README","doc":"> For more information, check the [module\n> documentation](https://hexdocs.pm/git_hooks) for each of the different\n> supported tasks.\n\n#### Mix task\n\nThis is the preferred option to run mix tasks, as it will provide the best\nexecution feedback.\n\nJust add in your config the mix tasks you want to run. You can also set the args\nto be used by the mix task:\n\n```elixir\nconfig :git_hooks,\n  verbose: true,\n  hooks: [\n    commit_msg: [\n      tasks: [\n        {:mix_task, :test},\n        {:mix_task, :format, [\"--dry-run\"]}\n      ]\n    ]\n  ]\n```\n\nBy default this library expects by default the following return values from mix tasks:\n\n```elixir\n0\n:ok\nnil\n```\n\nIf you want to support additional success return values from your mix tasks, you\ncan add them by adding the following configuration:\n\n```elixir\nconfig :git_hooks,\n  extra_success_returns: [\n    {:noop, []},\n    {:ok, []}\n  ]\n```\n\n#### Command\n\nTo run a simple command you can either declare a string or a tuple with the\ncommand you want to run. For example, having `\"mix test\"` and `{:cmd, \"mix\ntest\"}` in the hook `tasks` will be equivalent.\n\n> If you want to forward the git hook arguments, add the option\n> `include_hook_args: true`.\n\n```elixir\nconfig :git_hooks,\n  verbose: true,\n  hooks: [\n    commit_msg: [\n      tasks: [\n        {:cmd, \"echo 'test'\"},\n        {:cmd, \"elixir ./priv/test_task.ex\", include_hook_args: true},\n      ]\n    ]\n  ]\n```\n\n#### Executable file\n\nThe following configuration uses a script file to be run with a git hook. If you\nwant to forward the git hook arguments, add the option `include_hook_args:\ntrue`.\n\n```elixir\nconfig :git_hooks,\n  verbose: true,\n  hooks: [\n    commit_msg: [\n      tasks: [\n        {:file, \"./priv/test_script\"},\n        {:file, \"./priv/test_script_with_args\", include_hook_args: true},\n      ]\n    ]\n  ]\n```\n\nThe script file executed will receive the arguments from git, so you can use\nthem as you please.\n\n#### Elixir module\n\nIt is also possible to use Elixir modules to execute actions for a given git\nhook.\n\nJust add in your config the\n[MFA](https://hexdocs.pm/elixir/typespecs.html#built-in-types) (`{module,\nfunction, arity}`) definition:\n\n```elixir\nconfig :git_hooks,\n  verbose: true,\n  hooks: [\n    commit_msg: [\n      tasks: [\n        {MyModule, :execute, 2}\n      ]\n    ]\n  ]\n```\n\nTo check how many args you function should expect [check the git\ndocumentation](https://git-scm.com/docs/githooks) to know which parameters are\nbeing sent on each hook.","ref":"readme.html#task-types"},{"type":"extras","title":"Removing a hook - README","doc":"When a git hook configuration is removed, the installed hook will automatically\ndelete it.\n\nAny backup done at the moment will still be kept.","ref":"readme.html#removing-a-hook"},{"type":"extras","title":"Recipes - README","doc":"List of recipes that can be useful to setup your git hooks.","ref":"readme.html#recipes"},{"type":"extras","title":"Running pre-commit hook only for staged files - README","doc":"```elixir\n{:mix_task, \"credo\", [\"$(git diff --name-only --cached)\", \" --strict\"]}\n```","ref":"readme.html#running-pre-commit-hook-only-for-staged-files"},{"type":"extras","title":"Execution - README","doc":"","ref":"readme.html#execution"},{"type":"extras","title":"Automatic execution - README","doc":"The configured mix tasks will run automatically for each [git\nhook](https://git-scm.com/docs/githooks#_hooks).","ref":"readme.html#automatic-execution"},{"type":"extras","title":"Manual execution - README","doc":"You can also run manually any configured git hook as well.\n\nThe following example will run the pre_commit configuration:\n\n```bash\nmix git_hooks.run pre_commit\n```\n\nIt is also possible to run all the configured hooks:\n\n```bash\nmix git_hooks.run all\n```","ref":"readme.html#manual-execution"},{"type":"extras","title":"Copyright and License - README","doc":"Copyright © 2022-present Adrián Quintás\n\nSource code is released under [the MIT license](./LICENSE).","ref":"readme.html#copyright-and-license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}